summaryrefslogtreecommitdiff
path: root/src/nautilus-files-view.h
diff options
context:
space:
mode:
authorCarlos Soriano <csoriano@gnome.org>2016-04-07 21:51:52 +0200
committerCarlos Soriano <csoriano@gnome.org>2017-02-15 01:27:41 +0100
commit1d166b5e3b34195efe04df950a3f5397c2c99ef7 (patch)
tree8b6eee8bd8215fd9d9de8e285a7d24b9740f0ccb /src/nautilus-files-view.h
parent370b1ab77ead9059eb7bd58a5e63431242becd8d (diff)
downloadnautilus-1d166b5e3b34195efe04df950a3f5397c2c99ef7.tar.gz
views: add flow box based view
After all the rework on the window slots, views, and splitting the desktop, we are finally able to add a flow box based view for Nautilus. The GtkFlowBox is still not performance enough to be added as the default view, not even as an alternative in the user preferences. However, since the work on this is one of the biggest for Nautilus and gtk+, the decision was to merge a prototype in order to open the development, testing and iteration of the code in order to make it good enough for, in a not so far away future, have it as the main view. The work merged is not finished, and is an experiment and prototype in more things than just the GtkFlowBox, we want to create a single shared model with a complete MVC pattern between all the views. This will need quite a few iterations to get it right, but once is done right, I hope it's going to be good enough as an example to any application that wants multiple types of views with the new widgets of gtk+. This patch adds the GtkFlowBox view to be optionally used under a gsetting called use-experimental-views, turned off by default.
Diffstat (limited to 'src/nautilus-files-view.h')
-rw-r--r--src/nautilus-files-view.h10
1 files changed, 4 insertions, 6 deletions
diff --git a/src/nautilus-files-view.h b/src/nautilus-files-view.h
index 6e3cd5df6..7bf0521e3 100644
--- a/src/nautilus-files-view.h
+++ b/src/nautilus-files-view.h
@@ -57,12 +57,12 @@ struct _NautilusFilesViewClass {
*/
void (* begin_file_changes) (NautilusFilesView *view);
/* The 'add_file' signal is emitted to add one file to the view.
* It must be replaced by each subclass.
*/
- void (* add_file) (NautilusFilesView *view,
- NautilusFile *file,
- NautilusDirectory *directory);
+ void (* add_files) (NautilusFilesView *view,
+ GList *files,
+ NautilusDirectory *directory);
void (* remove_file) (NautilusFilesView *view,
NautilusFile *file,
NautilusDirectory *directory);
@@ -324,8 +324,6 @@ char * nautilus_files_view_get_title (NautilusFilesV
gboolean nautilus_files_view_supports_zooming (NautilusFilesView *view);
void nautilus_files_view_bump_zoom_level (NautilusFilesView *view,
int zoom_increment);
-void nautilus_files_view_zoom_to_level (NautilusFilesView *view,
- gint level);
gboolean nautilus_files_view_can_zoom_in (NautilusFilesView *view);
gboolean nautilus_files_view_can_zoom_out (NautilusFilesView *view);
void nautilus_files_view_update_menus (NautilusFilesView *view);
@@ -57,12 +57,12 @@ struct _NautilusFilesViewClass {
*/
void (* begin_file_changes) (NautilusFilesView *view);
- /* The 'add_file' signal is emitted to add one file to the view.
+ /* The 'add_files' signal is emitted to add a set of files to the view.
* It must be replaced by each subclass.
*/